package controller

import (
	"encoding/json"
	"fmt"
	"io"
	"net/http"

	"github.com/gofiber/fiber/v2"
	"ulmer-furs.de/pretix-proxy/v2/app/service"
	"ulmer-furs.de/pretix-proxy/v2/app/util"
	"ulmer-furs.de/pretix-proxy/v2/config"
	"ulmer-furs.de/pretix-proxy/v2/entities"
)

// @Description Get the attendies of an event by the name
func GetAttendiesByEvent(c *fiber.Ctx) error {
	name := c.Params("name")
	event, err := service.Get_db_event_by_name(name)
	if err != nil {
		return c.Status(404).SendString(err.Error())
	}
	req, err := http.NewRequest("GET", fmt.Sprintf("https://%s/api/v1/organizers/%s/events/%s/orders", config.Env.Domain, event.Organizer, event.Event), nil)
	if err != nil {
		return c.Status(500).SendString("Internal Server Error")
	}
	req.Header.Add("Authorization", fmt.Sprintf("Token %s", config.Env.ApiKeyPretix))
	resp, err := config.Client.Do(req)
	if err != nil {
		return c.Status(500).SendString("Internal Server Error")
	}
	respbody, err := io.ReadAll(resp.Body)
	defer resp.Body.Close()
	if err != nil {
		return c.Status(500).SendString("Internal Server Error")
	}
	var unmarshaled_resp entities.Pretix_Event
	if err := json.Unmarshal(respbody, &unmarshaled_resp); err != nil {
		return c.Status(500).SendString("Internal Server Error")
	}

	attendiesAtEvent := util.GetAttendiesFromPretixJson(unmarshaled_resp, event)
	c.JSON(attendiesAtEvent)
	return c.SendStatus(200)
}
