package util

import (
	"golang.org/x/exp/slices"
	"ulmer-furs.de/pretix-proxy/v2/entities"
)

func GetAttendiesFromPretixJson(pretixEvent entities.Pretix_Event, event entities.Db_Event) entities.Attendies {
	var attendies entities.Attendies
	var name string

	for _, order := range pretixEvent.Results {
		indexParticipation := slices.IndexFunc(order.Positions, func(p entities.Pretix_Position) bool { return p.Item == event.ItemIdParticipation })
		indexBadge := slices.IndexFunc(order.Positions, func(p entities.Pretix_Position) bool { return p.Item == event.ItemIdBadge })
		indexRestaurant := slices.IndexFunc(order.Positions, func(p entities.Pretix_Position) bool { return p.Item == event.ItemIdRestaurant })
		// Get the Name of the Attendie. We take the Name from the Badge, if none Badge ordered == anonymous
		if indexBadge != -1 {
			indexName := slices.IndexFunc(order.Positions[indexBadge].Answers, func(a entities.Pretix_Answer) bool { return a.QuestionsIdentififer == event.QuestionIdName })
			name = order.Positions[indexBadge].Answers[indexName].Answer
		} else {
			name = "Anonymous"
		}

		indexRole := slices.IndexFunc(order.Positions[indexParticipation].Answers, func(a entities.Pretix_Answer) bool { return a.QuestionsIdentififer == event.QuestionIdRole })
		role := order.Positions[indexParticipation].Answers[indexRole].OptionIdentifiers

		if slices.Contains(role, event.OptionIdSuiter) {
			attendies.Suiter = append(attendies.Suiter, name)
		} else if slices.Contains(role, event.OptionIdSpotter) {
			attendies.Spotter = append(attendies.Spotter, name)
		} else if slices.Contains(role, event.OptionIdPhotograph) {
			attendies.Photographers = append(attendies.Photographers, name)
		} else if slices.Contains(role, event.OptionIdGuest) {
			attendies.Guests = append(attendies.Guests, name)
		} else if slices.Contains(role, event.OptionIdSpecialAnimal) {
			attendies.Suiter = append(attendies.Suiter, name)
			attendies.Photographers = append(attendies.Photographers, name)
		}

		if indexRestaurant != -1 {
			attendies.Restaurant = append(attendies.Restaurant, name)
		}
	}

	return attendies
}
