package main

import (
	"embed"
	"log"

	"github.com/gofiber/fiber/v2/middleware/cors"
	"ulmer-furs.de/pretix-proxy/v2/app/routes"
	"ulmer-furs.de/pretix-proxy/v2/config"
)

//go:embed app/views/*
var viewFS embed.FS

func main() {
	config.LoadEnv()
	config.Connect()
	config.SetupValidator()
	config.SetupMiddlewares()
	config.SetupFiber(viewFS)

	if config.Env.Debug {
		config.App.Use(cors.New(cors.Config{
			AllowHeaders:     "Origin,Content-Type,Accept,Content-Length,Accept-Language,Accept-Encoding,Connection,Access-Control-Allow-Origin",
			AllowOrigins:     "*",
			AllowCredentials: true,
			AllowMethods:     "GET,POST,HEAD,PUT,DELETE,PATCH,OPTIONS",
		}))
	}

	routes.PublicRoutes(config.App)
	routes.PrivateRoutes(config.App)

	log.Fatal(config.App.Listen(":3000"))
}
